﻿using System;
using Windows.Devices.Sensors;
using Windows.UI.Popups;
using Windows.UI.Xaml.Navigation;

namespace RotationAndSnapDemo
{
  public sealed partial class SimpleOrientationSensorPage
  {
    private readonly SimpleOrientationSensor _orientationSensor;

    public SimpleOrientationSensorPage()
    {
      _orientationSensor = SimpleOrientationSensor.GetDefault();
      InitializeComponent();
    }

    protected override void OnNavigatedTo(NavigationEventArgs e)
    {
      if (_orientationSensor == null)
      {
        var messageDialog = new MessageDialog("No orientation sensor was found.");
        messageDialog.ShowAsync();
        return;
      }

      // If you comment the following line the demo will behave like the first example in
      // the tutorial. Removing the event handler 
      _orientationSensor.OrientationChanged += OrientationChanged;
      ShowOrientation(_orientationSensor.GetCurrentOrientation());
    }

    protected override void OnNavigatedFrom(NavigationEventArgs e)
    {
      _orientationSensor.OrientationChanged -= OrientationChanged;
      base.OnNavigatedFrom(e);
    }

    async void OrientationChanged(SimpleOrientationSensor sender,
      SimpleOrientationSensorOrientationChangedEventArgs args)
    {
      await Dispatcher.RunAsync(Windows.UI.Core.CoreDispatcherPriority.Normal,
        () => ShowOrientation(args.Orientation));
    }

    void ShowOrientation(SimpleOrientation simpleOrientation)
    {
      string orientation;

      switch (simpleOrientation)
      {
        case SimpleOrientation.Facedown:
          orientation = "facing down";
          break;
        case SimpleOrientation.Faceup:
          orientation = "facing up";
          break;
        case SimpleOrientation.NotRotated:
          orientation = "landscape";
          break;
        case SimpleOrientation.Rotated180DegreesCounterclockwise:
          orientation = "landscape-flipped";
          break;
        case SimpleOrientation.Rotated270DegreesCounterclockwise:
          orientation = "portrait";
          break;
        case SimpleOrientation.Rotated90DegreesCounterclockwise:
          orientation = "portrait-flipped";
          break;
        default:
          orientation = "unknown";
          break;
      }

      MyRotation.Text = "Current orientation: " + orientation;
    }
  }
}